==> hausmon_client-0.0.4-py3-none-any.whl: hausmon_client/client.py <==
from typing import Dict, List, Union
import logging

from urllib.parse import urlparse
from bravado.client import SwaggerClient
from bravado.requests_client import RequestsClient

log = logging.getLogger(__name__)


class HausMonClient:
    """Encapsulates HausMon api_client functionality."""

    def __init__(self, service_url: str, token: str) -> None:
        """Create a Swagger API client, load the Swagger definition from the provided service url, and set the
        authentication token for the domain name in the url.

        :param service_url: The base URL for the service, e.g. 'https://mon.hausnet.io/api', without a trailing slash.
        :param token:       The access token provided by the HausMon service.
        :raises:            Any exceptions that were raised during the Swagger client initialization, including
                            connection to the service.
        """
        host = urlparse(service_url).hostname
        # TODO: Get SSL verification working
        http_client = RequestsClient(ssl_verify=False)
        http_client.set_api_key(host=host, api_key=f'Token {token}', param_in='header', param_name='Authorization')
        # noinspection PyBroadException
        try:
            self.client = SwaggerClient.from_url(f'{service_url}/swagger.json', http_client=http_client)
        except Exception as e:
            log.exception(f"Failed to connect to hausmon client: url={service_url}")
            self.client = None
            raise e

    @property
    def connected(self) -> bool:
        return self.client is not None

    def list_devices(self) -> List[Dict]:
        """Get a list of devices belonging to the user associated with the auth token."""
        # noinspection PyUnresolvedReferences
        devices = self.client.devices.devices_list().response().result
        return devices

    def get_device(self, name: str) -> Union[Dict, None]:
        """Get a device by name, by iterating through all the devices.

        TODO: Add an API endpoint that directly fetches the device by name, instead of having to iterate.
        """
        devices = self.list_devices()
        for device in devices:
            if 'name' in device and device['name'] == name:
                return device
        return None

    def get_heartbeat(self, device_name: str) -> Union[Dict, None]:
        """Get a device's heartbeat.

        :return: The heartbeat (dynamic) object if a heartbeat exists for the device, otherwise "None"

        TODO: Add an API call to do this directly from the device name.
        """
        device = self.get_device(device_name)
        if not device or not device.heartbeat_id:
            return None
        # noinspection PyUnresolvedReferences
        heartbeat = self.client.heartbeats.heartbeats_read(id=device.heartbeat_id).response().result
        return heartbeat

    def send_heartbeat(self, heartbeat_id: int):
        """Send a heartbeat for a specific heartbeat definition (or device). """
        # noinspection PyUnresolvedReferences
        self.client.heartbeats.heartbeats_beat(id=heartbeat_id).response()

==> hausmon_client-0.0.5-py3-none-any.whl: hausmon_client/client.py <==
from typing import Dict, List, Union
import logging

import certifi
from urllib.parse import urlparse
from bravado.client import SwaggerClient
from bravado.requests_client import RequestsClient

log = logging.getLogger(__name__)


class HausMonClient:
    """Encapsulates HausMon api_client functionality."""

    def __init__(self, service_url: str, token: str) -> None:
        """Create a Swagger API client, load the Swagger definition from the provided service url, and set the
        authentication token for the domain name in the url.

        :param service_url: The base URL for the service, e.g. 'https://mon.hausnet.io/api', without a trailing slash.
        :param token:       The access token provided by the HausMon service.
        :raises:            Any exceptions that were raised during the Swagger client initialization, including
                            connection to the service.
        """
        host = urlparse(service_url).hostname
        http_client = RequestsClient(ssl_cert=certifi.where())
        http_client.set_api_key(host=host, api_key=f'Token {token}', param_in='header', param_name='Authorization')
        # noinspection PyBroadException
        try:
            self.client = SwaggerClient.from_url(f'{service_url}/swagger.json', http_client=http_client)
        except Exception as e:
            log.exception(f"Failed to connect to hausmon client: url={service_url}")
            self.client = None
            raise e

    @property
    def connected(self) -> bool:
        return self.client is not None

    def list_devices(self) -> List[Dict]:
        """Get a list of devices belonging to the user associated with the auth token."""
        # noinspection PyUnresolvedReferences
        devices = self.client.devices.devices_list().response().result
        return devices

    def get_device(self, name: str) -> Union[Dict, None]:
        """Get a device by name, by iterating through all the devices.

        TODO: Add an API endpoint that directly fetches the device by name, instead of having to iterate.
        """
        devices = self.list_devices()
        for device in devices:
            if 'name' in device and device['name'] == name:
                return device
        return None

    def get_heartbeat(self, device_name: str) -> Union[Dict, None]:
        """Get a device's heartbeat.

        :return: The heartbeat (dynamic) object if a heartbeat exists for the device, otherwise "None"

        TODO: Add an API call to do this directly from the device name.
        """
        device = self.get_device(device_name)
        if not device or not device.heartbeat_id:
            return None
        # noinspection PyUnresolvedReferences
        heartbeat = self.client.heartbeats.heartbeats_read(id=device.heartbeat_id).response().result
        return heartbeat

    def send_heartbeat(self, heartbeat_id: int):
        """Send a heartbeat for a specific heartbeat definition (or device). """
        # noinspection PyUnresolvedReferences
        self.client.heartbeats.heartbeats_beat(id=heartbeat_id).response()
